<?php

return [
    'Names' => [
        'af' => 'ཨཕ་རི་ཀཱནས་ཁ',
        'af_NA' => 'ཨཕ་རི་ཀཱནས་ཁ། (ན་མི་བི་ཡ།)',
        'af_ZA' => 'ཨཕ་རི་ཀཱནས་ཁ། (སཱའུཐ་ ཨཕ་རི་ཀ།)',
        'am' => 'ཨམ་ཧ་རིཀ་ཁ',
        'am_ET' => 'ཨམ་ཧ་རིཀ་ཁ། (ཨི་ཐི་ཡོ་པི་ཡ།)',
        'ar' => 'ཨེ་ར་བིཀ་ཁ',
        'ar_001' => 'ཨེ་ར་བིཀ་ཁ། (འཛམ་གླིང༌།)',
        'ar_AE' => 'ཨེ་ར་བིཀ་ཁ། (ཡུ་ནཱའི་ཊེཌ་ ཨ་རབ་ ཨེ་མེ་རེཊས།)',
        'ar_BH' => 'ཨེ་ར་བིཀ་ཁ། (བྷ་རེན།)',
        'ar_DJ' => 'ཨེ་ར་བིཀ་ཁ། (ཇི་བྷུ་ཊི།)',
        'ar_DZ' => 'ཨེ་ར་བིཀ་ཁ། (ཨཱལ་ཇི་རི་ཡ།)',
        'ar_EG' => 'ཨེ་ར་བིཀ་ཁ། (ཨི་ཇིབཊ།)',
        'ar_EH' => 'ཨེ་ར་བིཀ་ཁ། (ནུབ་ཕྱོགས་ ས་ཧཱ་ར།)',
        'ar_ER' => 'ཨེ་ར་བིཀ་ཁ། (ཨེ་རི་ཊྲེ་ཡ།)',
        'ar_IL' => 'ཨེ་ར་བིཀ་ཁ། (ཨིས་ར་ཡེལ།)',
        'ar_IQ' => 'ཨེ་ར་བིཀ་ཁ། (ཨི་རཱཀ།)',
        'ar_JO' => 'ཨེ་ར་བིཀ་ཁ། (ཇོར་ཌན།)',
        'ar_KM' => 'ཨེ་ར་བིཀ་ཁ། (ཀོ་མོ་རོས།)',
        'ar_KW' => 'ཨེ་ར་བིཀ་ཁ། (ཀུ་ཝེཊ།)',
        'ar_LB' => 'ཨེ་ར་བིཀ་ཁ། (ལེ་བ་ནོན།)',
        'ar_LY' => 'ཨེ་ར་བིཀ་ཁ། (ལི་བི་ཡ།)',
        'ar_MA' => 'ཨེ་ར་བིཀ་ཁ། (མོ་རོ་ཀོ།)',
        'ar_MR' => 'ཨེ་ར་བིཀ་ཁ། (མོ་རི་ཊེ་ནི་ཡ།)',
        'ar_OM' => 'ཨེ་ར་བིཀ་ཁ། (ཨོ་མཱན།)',
        'ar_PS' => 'ཨེ་ར་བིཀ་ཁ། (པེ་ལིསི་ཊི་ནི་ཡན་ཊེ་རི་ཐོ་རི།)',
        'ar_QA' => 'ཨེ་ར་བིཀ་ཁ། (ཀ་ཊར།)',
        'ar_SA' => 'ཨེ་ར་བིཀ་ཁ། (སཱཝ་དི་ ཨ་རེ་བྷི་ཡ།)',
        'ar_SD' => 'ཨེ་ར་བིཀ་ཁ། (སུ་ཌཱན།)',
        'ar_SO' => 'ཨེ་ར་བིཀ་ཁ། (སོ་མ་ལི་ཡ།)',
        'ar_SS' => 'ཨེ་ར་བིཀ་ཁ། (སཱའུཐ་ སུ་ཌཱན།)',
        'ar_SY' => 'ཨེ་ར་བིཀ་ཁ། (སི་རི་ཡ།)',
        'ar_TD' => 'ཨེ་ར་བིཀ་ཁ། (ཅཱཌ།)',
        'ar_TN' => 'ཨེ་ར་བིཀ་ཁ། (ཊུ་ནི་ཤི་ཡ།)',
        'ar_YE' => 'ཨེ་ར་བིཀ་ཁ། (ཡེ་མེན།)',
        'as' => 'ཨ་ས་མིས་ཁ',
        'as_IN' => 'ཨ་ས་མིས་ཁ། (རྒྱ་གར།)',
        'az' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ',
        'az_AZ' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ། (ཨ་ཛར་བྷའི་ཇཱན།)',
        'az_Cyrl' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ།)',
        'az_Cyrl_AZ' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, ཨ་ཛར་བྷའི་ཇཱན།)',
        'az_Latn' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'az_Latn_AZ' => 'ཨ་ཛར་བྷའི་ཇཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ་, ཨ་ཛར་བྷའི་ཇཱན།)',
        'be' => 'བེལ་ཨ་རུས་ཁ',
        'be_BY' => 'བེལ་ཨ་རུས་ཁ། (བེལ་ཨ་རུ་སུ།)',
        'bg' => 'བཱལ་གེ་རི་ཡཱན་ཁ',
        'bg_BG' => 'བཱལ་གེ་རི་ཡཱན་ཁ། (བུལ་ག་རི་ཡ།)',
        'bn' => 'བངྒ་ལ་ཁ',
        'bn_BD' => 'བངྒ་ལ་ཁ། (བངྒ་ལ་དེཤ།)',
        'bn_IN' => 'བངྒ་ལ་ཁ། (རྒྱ་གར།)',
        'bo' => 'བོད་ཁ',
        'bo_CN' => 'བོད་ཁ། (རྒྱ་ནག།)',
        'bo_IN' => 'བོད་ཁ། (རྒྱ་གར།)',
        'bs' => 'བྷོས་ནི་ཡཱན་ཁ',
        'bs_BA' => 'བྷོས་ནི་ཡཱན་ཁ། (བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'bs_Cyrl' => 'བྷོས་ནི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ།)',
        'bs_Cyrl_BA' => 'བྷོས་ནི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'bs_Latn' => 'བྷོས་ནི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'bs_Latn_BA' => 'བྷོས་ནི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ་, བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'ca' => 'ཀེ་ཊ་ལཱན་ཁ',
        'ca_AD' => 'ཀེ་ཊ་ལཱན་ཁ། (ཨཱན་དོ་ར།)',
        'ca_ES' => 'ཀེ་ཊ་ལཱན་ཁ། (ཨིས་པེན།)',
        'ca_FR' => 'ཀེ་ཊ་ལཱན་ཁ། (ཕྲཱནས།)',
        'ca_IT' => 'ཀེ་ཊ་ལཱན་ཁ། (ཨི་ཊ་ལི།)',
        'cs' => 'ཅེཀ་ཁ',
        'cs_CZ' => 'ཅེཀ་ཁ། (ཅེཀ་ རི་པབ་ལིཀ།)',
        'cy' => 'ཝེལཤ་ཁ',
        'cy_GB' => 'ཝེལཤ་ཁ། (ཡུ་ནཱའི་ཊེཌ་ ཀིང་ཌམ།)',
        'da' => 'ཌེ་ནིཤ་ཁ',
        'da_DK' => 'ཌེ་ནིཤ་ཁ། (ཌེན་མཱཀ།)',
        'da_GL' => 'ཌེ་ནིཤ་ཁ། (གིརཱིན་ལནཌ྄།)',
        'de' => 'ཇཱར་མཱན་ཁ',
        'de_AT' => 'ཇཱར་མཱན་ཁ། (ཨཱོས་ཊྲི་ཡ།)',
        'de_BE' => 'ཇཱར་མཱན་ཁ། (བྷེལ་ཇམ།)',
        'de_CH' => 'ཇཱར་མཱན་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'de_DE' => 'ཇཱར་མཱན་ཁ། (ཇཱར་མ་ནི།)',
        'de_IT' => 'ཇཱར་མཱན་ཁ། (ཨི་ཊ་ལི།)',
        'de_LI' => 'ཇཱར་མཱན་ཁ། (ལིཀ་ཏནས་ཏ་ཡིན།)',
        'de_LU' => 'ཇཱར་མཱན་ཁ། (ལག་ཛམ་བོརྒ།)',
        'dz' => 'རྫོང་ཁ',
        'dz_BT' => 'རྫོང་ཁ། (འབྲུག།)',
        'el' => 'གྲིཀ་ཁ',
        'el_CY' => 'གྲིཀ་ཁ། (སཱའི་པྲས།)',
        'el_GR' => 'གྲིཀ་ཁ། (གིརིས྄།)',
        'en' => 'ཨིང་ལིཤ་ཁ',
        'en_001' => 'ཨིང་ལིཤ་ཁ། (འཛམ་གླིང༌།)',
        'en_150' => 'ཨིང་ལིཤ་ཁ། (ཡུ་རོབ།)',
        'en_AE' => 'ཨིང་ལིཤ་ཁ། (ཡུ་ནཱའི་ཊེཌ་ ཨ་རབ་ ཨེ་མེ་རེཊས།)',
        'en_AG' => 'ཨིང་ལིཤ་ཁ། (ཨན་ཊི་གུ་ཝ་ ཨེནཌ་ བྷར་བྷུ་ཌ།)',
        'en_AI' => 'ཨིང་ལིཤ་ཁ། (ཨང་གི་ལ།)',
        'en_AS' => 'ཨིང་ལིཤ་ཁ། (ས་མོ་ཨ་ཡུ་ཨེས་ཨེ་མངའ་ཁོངས།)',
        'en_AT' => 'ཨིང་ལིཤ་ཁ། (ཨཱོས་ཊྲི་ཡ།)',
        'en_AU' => 'ཨིང་ལིཤ་ཁ། (ཨཱོས་ཊྲེལ་ལི་ཡ།)',
        'en_BB' => 'ཨིང་ལིཤ་ཁ། (བྷར་བེ་ཌོས།)',
        'en_BE' => 'ཨིང་ལིཤ་ཁ། (བྷེལ་ཇམ།)',
        'en_BI' => 'ཨིང་ལིཤ་ཁ། (བྷུ་རུན་ཌི།)',
        'en_BM' => 'ཨིང་ལིཤ་ཁ། (བར་མུ་ཌ།)',
        'en_BS' => 'ཨིང་ལིཤ་ཁ། (བྷ་ཧ་མས྄།)',
        'en_BW' => 'ཨིང་ལིཤ་ཁ། (བྷོཙ་ཝ་ན།)',
        'en_BZ' => 'ཨིང་ལིཤ་ཁ། (བྷེ་ལིཛ།)',
        'en_CA' => 'ཨིང་ལིཤ་ཁ། (ཀེ་ན་ཌ།)',
        'en_CC' => 'ཨིང་ལིཤ་ཁ། (ཀོ་ཀོས་གླིང་ཚོམ།)',
        'en_CH' => 'ཨིང་ལིཤ་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'en_CK' => 'ཨིང་ལིཤ་ཁ། (ཀུག་གླིང་ཚོམ།)',
        'en_CM' => 'ཨིང་ལིཤ་ཁ། (ཀེ་མ་རུན།)',
        'en_CX' => 'ཨིང་ལིཤ་ཁ། (ཁི་རིསྟ་མེས་མཚོ་གླིང།)',
        'en_CY' => 'ཨིང་ལིཤ་ཁ། (སཱའི་པྲས།)',
        'en_DE' => 'ཨིང་ལིཤ་ཁ། (ཇཱར་མ་ནི།)',
        'en_DK' => 'ཨིང་ལིཤ་ཁ། (ཌེན་མཱཀ།)',
        'en_DM' => 'ཨིང་ལིཤ་ཁ། (ཌོ་མི་ནི་ཀ།)',
        'en_ER' => 'ཨིང་ལིཤ་ཁ། (ཨེ་རི་ཊྲེ་ཡ།)',
        'en_FI' => 'ཨིང་ལིཤ་ཁ། (ཕིན་ལེནཌ།)',
        'en_FJ' => 'ཨིང་ལིཤ་ཁ། (ཕི་ཇི།)',
        'en_FK' => 'ཨིང་ལིཤ་ཁ། (ཕལྐ་ལནྜ་གླིང་ཚོམ།)',
        'en_FM' => 'ཨིང་ལིཤ་ཁ། (མའི་ཀྲོ་ནི་ཤི་ཡ།)',
        'en_GB' => 'ཨིང་ལིཤ་ཁ། (ཡུ་ནཱའི་ཊེཌ་ ཀིང་ཌམ།)',
        'en_GD' => 'ཨིང་ལིཤ་ཁ། (གྲྀ་ན་ཌ།)',
        'en_GG' => 'ཨིང་ལིཤ་ཁ། (གུ་ཨེརྣ་སི།)',
        'en_GH' => 'ཨིང་ལིཤ་ཁ། (གྷ་ན།)',
        'en_GI' => 'ཨིང་ལིཤ་ཁ། (ཇིབ་རཱལ་ཊར།)',
        'en_GM' => 'ཨིང་ལིཤ་ཁ། (གྷེམ་བི་ཡ།)',
        'en_GU' => 'ཨིང་ལིཤ་ཁ། (གུ་འམ་ མཚོ་གླིང།)',
        'en_GY' => 'ཨིང་ལིཤ་ཁ། (གྷ་ཡ་ན།)',
        'en_HK' => 'ཨིང་ལིཤ་ཁ། (ཧོང་ཀོང་ཅཱའི་ན།)',
        'en_IE' => 'ཨིང་ལིཤ་ཁ། (ཨཱ་ཡ་ལེནཌ།)',
        'en_IL' => 'ཨིང་ལིཤ་ཁ། (ཨིས་ར་ཡེལ།)',
        'en_IM' => 'ཨིང་ལིཤ་ཁ། (ཨ་ཡུལ་ ཨོཕ་ མཱན།)',
        'en_IN' => 'ཨིང་ལིཤ་ཁ། (རྒྱ་གར།)',
        'en_IO' => 'ཨིང་ལིཤ་ཁ། (བྲི་ཊིཤ་རྒྱ་གར་གྱི་རྒྱ་མཚོ་ས་ཁོངས།)',
        'en_JE' => 'ཨིང་ལིཤ་ཁ། (ཇེར་སི།)',
        'en_JM' => 'ཨིང་ལིཤ་ཁ། (ཇཱ་མཻ་ཀ།)',
        'en_KE' => 'ཨིང་ལིཤ་ཁ། (ཀེན་ཡ།)',
        'en_KI' => 'ཨིང་ལིཤ་ཁ། (ཀི་རི་བ་ཏི་མཚོ་གླིང།)',
        'en_KN' => 'ཨིང་ལིཤ་ཁ། (སེནཊ་ ཀིཊས་ དང་ ནེ་བིས།)',
        'en_KY' => 'ཨིང་ལིཤ་ཁ། (ཁེ་མེན་གླིང་ཚོམ།)',
        'en_LC' => 'ཨིང་ལིཤ་ཁ། (སེནཊ་ ལུ་སི་ཡ།)',
        'en_LR' => 'ཨིང་ལིཤ་ཁ། (ལཱའི་བེ་རི་ཡ།)',
        'en_LS' => 'ཨིང་ལིཤ་ཁ། (ལཻ་སོ་ཐོ།)',
        'en_MG' => 'ཨིང་ལིཤ་ཁ། (མ་དཱ་གེས་ཀར།)',
        'en_MH' => 'ཨིང་ལིཤ་ཁ། (མར་ཤེལ་གླིང་ཚོམ།)',
        'en_MO' => 'ཨིང་ལིཤ་ཁ། (མཀ་ཨའུ་ཅཱའི་ན།)',
        'en_MP' => 'ཨིང་ལིཤ་ཁ། (བྱང་ཕྱོགས་ཀྱི་མ་ར་ཡ་ན་གླིང་ཚོམ།)',
        'en_MS' => 'ཨིང་ལིཤ་ཁ། (མོན་ས་རཊ།)',
        'en_MT' => 'ཨིང་ལིཤ་ཁ། (མཱལ་ཊ།)',
        'en_MU' => 'ཨིང་ལིཤ་ཁ། (མོ་རི་ཤཱས།)',
        'en_MV' => 'ཨིང་ལིཤ་ཁ། (མཱལ་དིབས།)',
        'en_MW' => 'ཨིང་ལིཤ་ཁ། (མ་ལ་ཝི།)',
        'en_MY' => 'ཨིང་ལིཤ་ཁ། (མ་ལེ་ཤི་ཡ།)',
        'en_NA' => 'ཨིང་ལིཤ་ཁ། (ན་མི་བི་ཡ།)',
        'en_NF' => 'ཨིང་ལིཤ་ཁ། (ནོར་ཕོལཀ་མཚོ་གླིང༌།)',
        'en_NG' => 'ཨིང་ལིཤ་ཁ། (ནཱའི་ཇི་རི་ཡ།)',
        'en_NL' => 'ཨིང་ལིཤ་ཁ། (ནེ་དར་ལནཌས྄།)',
        'en_NR' => 'ཨིང་ལིཤ་ཁ། (ནའུ་རུ་།)',
        'en_NU' => 'ཨིང་ལིཤ་ཁ། (ནི་ཨུ་ཨཻ།)',
        'en_NZ' => 'ཨིང་ལིཤ་ཁ། (ནིའུ་ཛི་ལེནཌ།)',
        'en_PG' => 'ཨིང་ལིཤ་ཁ། (པ་པུ་ ནིའུ་གི་ནི།)',
        'en_PH' => 'ཨིང་ལིཤ་ཁ། (ཕི་ལི་པིནས།)',
        'en_PK' => 'ཨིང་ལིཤ་ཁ། (པ་ཀི་སཏཱན།)',
        'en_PN' => 'ཨིང་ལིཤ་ཁ། (པིཊ་ཀེ་ཡེརན་གླིང་ཚོམ།)',
        'en_PR' => 'ཨིང་ལིཤ་ཁ། (པུ་འེར་ཊོ་རི་ཁོ།)',
        'en_PW' => 'ཨིང་ལིཤ་ཁ། (པ་ལའུ།)',
        'en_RW' => 'ཨིང་ལིཤ་ཁ། (རུ་ཝན་ཌ།)',
        'en_SB' => 'ཨིང་ལིཤ་ཁ། (སོ་ལོ་མོན་ གླིང་ཚོམ།)',
        'en_SC' => 'ཨིང་ལིཤ་ཁ། (སེ་ཤཱལས།)',
        'en_SD' => 'ཨིང་ལིཤ་ཁ། (སུ་ཌཱན།)',
        'en_SE' => 'ཨིང་ལིཤ་ཁ། (སུའི་ཌེན།)',
        'en_SG' => 'ཨིང་ལིཤ་ཁ། (སིང་ག་པོར།)',
        'en_SH' => 'ཨིང་ལིཤ་ཁ། (སེནཊ་ ཧེ་ལི་ན།)',
        'en_SI' => 'ཨིང་ལིཤ་ཁ། (སུ་ལོ་བི་ནི་ཡ།)',
        'en_SL' => 'ཨིང་ལིཤ་ཁ། (སི་ར་ ལི་འོན།)',
        'en_SS' => 'ཨིང་ལིཤ་ཁ། (སཱའུཐ་ སུ་ཌཱན།)',
        'en_SX' => 'ཨིང་ལིཤ་ཁ། (སིནཊ་ མཱར་ཊེན།)',
        'en_SZ' => 'ཨིང་ལིཤ་ཁ། (སུ་ཝ་ཛི་ལེནཌ།)',
        'en_TC' => 'ཨིང་ལིཤ་ཁ། (ཏུརྐས྄་ ཨེནཌ་ ཀ་ཀོས་གླིང་ཚོམ།)',
        'en_TK' => 'ཨིང་ལིཤ་ཁ། (ཏོ་ཀེ་ལའུ་ མཚོ་གླིང།)',
        'en_TO' => 'ཨིང་ལིཤ་ཁ། (ཊོང་གྷ།)',
        'en_TT' => 'ཨིང་ལིཤ་ཁ། (ཊི་ནི་ཌཱཌ་ ཨེནཌ་ ཊོ་བྷེ་གྷོ།)',
        'en_TV' => 'ཨིང་ལིཤ་ཁ། (ཏུ་ཝ་ལུ།)',
        'en_TZ' => 'ཨིང་ལིཤ་ཁ། (ཊཱན་ཛཱ་ནི་ཡ།)',
        'en_UG' => 'ཨིང་ལིཤ་ཁ། (ཡུ་གྷན་ཌ།)',
        'en_UM' => 'ཨིང་ལིཤ་ཁ། (ཡུ་ཨེས་གྱི་མཐའ་མཚམས་མཚོ་གླིང་།)',
        'en_US' => 'ཨིང་ལིཤ་ཁ། (ཡུ་ཨེས་ཨེ།)',
        'en_VC' => 'ཨིང་ལིཤ་ཁ། (སེནཊ་ཝིན་སེནཌ྄ ཨེནཌ་ གི་རེ་ན་དིནས྄།)',
        'en_VG' => 'ཨིང་ལིཤ་ཁ། (ཝརཇིན་གླིང་ཚོམ་ བྲཱི་ཊིཤ་མངའ་ཁོངས།)',
        'en_VI' => 'ཨིང་ལིཤ་ཁ། (ཝརཇིན་གླིང་ཚོམ་ ཡུ་ཨེས་ཨེ་མངའ་ཁོངས།)',
        'en_VU' => 'ཨིང་ལིཤ་ཁ། (ཝ་ནུ་ཨ་ཏུ།)',
        'en_WS' => 'ཨིང་ལིཤ་ཁ། (ས་མོ་ཨ།)',
        'en_ZA' => 'ཨིང་ལིཤ་ཁ། (སཱའུཐ་ ཨཕ་རི་ཀ།)',
        'en_ZM' => 'ཨིང་ལིཤ་ཁ། (ཛམ་བྷི་ཡ།)',
        'en_ZW' => 'ཨིང་ལིཤ་ཁ། (ཛིམ་བྷབ་ཝེ།)',
        'eo' => 'ཨེས་པ་རཱན་ཏོ་ཁ',
        'eo_001' => 'ཨེས་པ་རཱན་ཏོ་ཁ། (འཛམ་གླིང༌།)',
        'es' => 'ཨིས་པེ་ནིཤ་ཁ',
        'es_419' => 'ཨིས་པེ་ནིཤ་ཁ། (ལེ་ཊིནཨ་མི་རི་ཀ།)',
        'es_AR' => 'ཨིས་པེ་ནིཤ་ཁ། (ཨར་ཇེན་ཊི་ན།)',
        'es_BO' => 'ཨིས་པེ་ནིཤ་ཁ། (བྷེ་ལི་བི་ཡ།)',
        'es_BR' => 'ཨིས་པེ་ནིཤ་ཁ། (བྲ་ཛིལ།)',
        'es_BZ' => 'ཨིས་པེ་ནིཤ་ཁ། (བྷེ་ལིཛ།)',
        'es_CL' => 'ཨིས་པེ་ནིཤ་ཁ། (ཅི་ལི།)',
        'es_CO' => 'ཨིས་པེ་ནིཤ་ཁ། (ཀོ་ལོམ་བྷི་ཡ།)',
        'es_CR' => 'ཨིས་པེ་ནིཤ་ཁ། (ཀོས་ཊ་རི་ཀ།)',
        'es_CU' => 'ཨིས་པེ་ནིཤ་ཁ། (ཀིའུ་བྷ།)',
        'es_DO' => 'ཨིས་པེ་ནིཤ་ཁ། (ཌོ་མི་ནི་ཀཱན་ རི་པབ་ལིཀ།)',
        'es_EC' => 'ཨིས་པེ་ནིཤ་ཁ། (ཨེ་ཁྭ་ཌོར།)',
        'es_ES' => 'ཨིས་པེ་ནིཤ་ཁ། (ཨིས་པེན།)',
        'es_GQ' => 'ཨིས་པེ་ནིཤ་ཁ། (ཨེ་ཀུ་ཊོ་རེལ་ གི་ནི།)',
        'es_GT' => 'ཨིས་པེ་ནིཤ་ཁ། (གྷོ་ཊ་མ་ལ།)',
        'es_HN' => 'ཨིས་པེ་ནིཤ་ཁ། (ཧཱན་ཌུ་རཱས྄།)',
        'es_MX' => 'ཨིས་པེ་ནིཤ་ཁ། (མེཀ་སི་ཀོ།)',
        'es_NI' => 'ཨིས་པེ་ནིཤ་ཁ། (ནི་ཀྲ་ཝ་ག།)',
        'es_PA' => 'ཨིས་པེ་ནིཤ་ཁ། (པ་ན་མ།)',
        'es_PE' => 'ཨིས་པེ་ནིཤ་ཁ། (པེ་རུ།)',
        'es_PH' => 'ཨིས་པེ་ནིཤ་ཁ། (ཕི་ལི་པིནས།)',
        'es_PR' => 'ཨིས་པེ་ནིཤ་ཁ། (པུ་འེར་ཊོ་རི་ཁོ།)',
        'es_PY' => 'ཨིས་པེ་ནིཤ་ཁ། (པ་ར་གུ་ཝའི།)',
        'es_SV' => 'ཨིས་པེ་ནིཤ་ཁ། (ཨེལ་སལ་བ་ཌོར།)',
        'es_US' => 'ཨིས་པེ་ནིཤ་ཁ། (ཡུ་ཨེས་ཨེ།)',
        'es_UY' => 'ཨིས་པེ་ནིཤ་ཁ། (ཡུ་རུ་གུ་ཝའི།)',
        'es_VE' => 'ཨིས་པེ་ནིཤ་ཁ། (བེ་ནི་ཛུ་ཝེ་ལ།)',
        'et' => 'ཨེས་ཊོ་ནི་ཡཱན་ཁ',
        'et_EE' => 'ཨེས་ཊོ་ནི་ཡཱན་ཁ། (ཨེས་ཊོ་ནི་ཡ།)',
        'eu' => 'བཱསཀ་ཁ',
        'eu_ES' => 'བཱསཀ་ཁ། (ཨིས་པེན།)',
        'fa' => 'པར་ཤི་ཡཱན་ཁ',
        'fa_AF' => 'པར་ཤི་ཡཱན་ཁ། (ཨཕ་གྷ་ནི་སཏཱན།)',
        'fa_IR' => 'པར་ཤི་ཡཱན་ཁ། (ཨི་རཱན།)',
        'fi' => 'ཕི་ནིཤ་ཁ',
        'fi_FI' => 'ཕི་ནིཤ་ཁ། (ཕིན་ལེནཌ།)',
        'fo' => 'ཕཱ་རོ་ཨིས་ཁ',
        'fo_DK' => 'ཕཱ་རོ་ཨིས་ཁ། (ཌེན་མཱཀ།)',
        'fo_FO' => 'ཕཱ་རོ་ཨིས་ཁ། (ཕཱའེ་རོ་གླིང་ཚོམ།)',
        'fr' => 'ཕྲནཅ་ཁ',
        'fr_BE' => 'ཕྲནཅ་ཁ། (བྷེལ་ཇམ།)',
        'fr_BF' => 'ཕྲནཅ་ཁ། (བྷར་ཀི་ན་ ཕེ་སོ།)',
        'fr_BI' => 'ཕྲནཅ་ཁ། (བྷུ་རུན་ཌི།)',
        'fr_BJ' => 'ཕྲནཅ་ཁ། (བྷེ་ནིན།)',
        'fr_BL' => 'ཕྲནཅ་ཁ། (སེནཊ་ བར་ཐོ་ལོམ་མིའུ།)',
        'fr_CA' => 'ཕྲནཅ་ཁ། (ཀེ་ན་ཌ།)',
        'fr_CD' => 'ཕྲནཅ་ཁ། (ཀོང་གྷོ ཀིན་ཤ་ས།)',
        'fr_CF' => 'ཕྲནཅ་ཁ། (སེན་ཊལ་ ཨཕ་རི་ཀཱན་ རི་པབ་ལིཀ།)',
        'fr_CG' => 'ཕྲནཅ་ཁ། (ཀོང་གྷོ བྷྲ་ཛ་བིལ།)',
        'fr_CH' => 'ཕྲནཅ་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'fr_CI' => 'ཕྲནཅ་ཁ། (ཀོ་ཊེ་ ཌི་ཨི་ཝོ་རེ།)',
        'fr_CM' => 'ཕྲནཅ་ཁ། (ཀེ་མ་རུན།)',
        'fr_DJ' => 'ཕྲནཅ་ཁ། (ཇི་བྷུ་ཊི།)',
        'fr_DZ' => 'ཕྲནཅ་ཁ། (ཨཱལ་ཇི་རི་ཡ།)',
        'fr_FR' => 'ཕྲནཅ་ཁ། (ཕྲཱནས།)',
        'fr_GA' => 'ཕྲནཅ་ཁ། (གྷ་བྷོན།)',
        'fr_GF' => 'ཕྲནཅ་ཁ། (གུའི་ཡ་ན་ ཕྲནས྄་མངའ་ཁོངས།)',
        'fr_GN' => 'ཕྲནཅ་ཁ། (གྷི་ནི།)',
        'fr_GP' => 'ཕྲནཅ་ཁ། (གོ་ཌེ་ལུ་པེ།)',
        'fr_GQ' => 'ཕྲནཅ་ཁ། (ཨེ་ཀུ་ཊོ་རེལ་ གི་ནི།)',
        'fr_HT' => 'ཕྲནཅ་ཁ། (ཧེ་ཊི།)',
        'fr_KM' => 'ཕྲནཅ་ཁ། (ཀོ་མོ་རོས།)',
        'fr_LU' => 'ཕྲནཅ་ཁ། (ལག་ཛམ་བོརྒ།)',
        'fr_MA' => 'ཕྲནཅ་ཁ། (མོ་རོ་ཀོ།)',
        'fr_MC' => 'ཕྲནཅ་ཁ། (མོ་ན་ཀོ།)',
        'fr_MF' => 'ཕྲནཅ་ཁ། (སེནཊ་ མཱར་ཊིན།)',
        'fr_MG' => 'ཕྲནཅ་ཁ། (མ་དཱ་གེས་ཀར།)',
        'fr_ML' => 'ཕྲནཅ་ཁ། (མཱ་ལི།)',
        'fr_MQ' => 'ཕྲནཅ་ཁ། (མཱར་ཊི་ནིཀ།)',
        'fr_MR' => 'ཕྲནཅ་ཁ། (མོ་རི་ཊེ་ནི་ཡ།)',
        'fr_MU' => 'ཕྲནཅ་ཁ། (མོ་རི་ཤཱས།)',
        'fr_NC' => 'ཕྲནཅ་ཁ། (ནིའུ་ཀ་ལི་དོ་ནི་ཡ།)',
        'fr_NE' => 'ཕྲནཅ་ཁ། (ནཱའི་ཇཱ།)',
        'fr_PF' => 'ཕྲནཅ་ཁ། (ཕྲཱནས྄་ཀྱི་པོ་ལི་ནི་ཤི་ཡ།)',
        'fr_PM' => 'ཕྲནཅ་ཁ། (སིནཊ་པི་ཡེར་ ཨེནཌ་ མིཀོ་ལེན།)',
        'fr_RE' => 'ཕྲནཅ་ཁ། (རེ་ཡུ་ནི་ཡོན།)',
        'fr_RW' => 'ཕྲནཅ་ཁ། (རུ་ཝན་ཌ།)',
        'fr_SC' => 'ཕྲནཅ་ཁ། (སེ་ཤཱལས།)',
        'fr_SN' => 'ཕྲནཅ་ཁ། (སེ་ནི་གྷལ།)',
        'fr_SY' => 'ཕྲནཅ་ཁ། (སི་རི་ཡ།)',
        'fr_TD' => 'ཕྲནཅ་ཁ། (ཅཱཌ།)',
        'fr_TG' => 'ཕྲནཅ་ཁ། (ཊོ་གྷོ།)',
        'fr_TN' => 'ཕྲནཅ་ཁ། (ཊུ་ནི་ཤི་ཡ།)',
        'fr_VU' => 'ཕྲནཅ་ཁ། (ཝ་ནུ་ཨ་ཏུ།)',
        'fr_WF' => 'ཕྲནཅ་ཁ། (ཝལ་ལིས྄་ ཨེནཌ་ ཕུ་ཏུ་ན་།)',
        'fr_YT' => 'ཕྲནཅ་ཁ། (མེ་ཡོཊ།)',
        'fy' => 'ནུབ་ཕྼི་སི་ཡན་ཁ',
        'fy_NL' => 'ནུབ་ཕྼི་སི་ཡན་ཁ། (ནེ་དར་ལནཌས྄།)',
        'ga' => 'ཨཱའི་རིཤ་ཁ',
        'ga_GB' => 'ཨཱའི་རིཤ་ཁ། (ཡུ་ནཱའི་ཊེཌ་ ཀིང་ཌམ།)',
        'ga_IE' => 'ཨཱའི་རིཤ་ཁ། (ཨཱ་ཡ་ལེནཌ།)',
        'gl' => 'གལ་ཨིས་ཨི་ཡན་ཁ',
        'gl_ES' => 'གལ་ཨིས་ཨི་ཡན་ཁ། (ཨིས་པེན།)',
        'gu' => 'གུ་ཇ་ར་ཏི་ཁ',
        'gu_IN' => 'གུ་ཇ་ར་ཏི་ཁ། (རྒྱ་གར།)',
        'ha' => 'ཧཝ་ས་ཁ',
        'ha_GH' => 'ཧཝ་ས་ཁ། (གྷ་ན།)',
        'ha_NE' => 'ཧཝ་ས་ཁ། (ནཱའི་ཇཱ།)',
        'ha_NG' => 'ཧཝ་ས་ཁ། (ནཱའི་ཇི་རི་ཡ།)',
        'he' => 'ཧེ་བྲུ་ཁ',
        'he_IL' => 'ཧེ་བྲུ་ཁ། (ཨིས་ར་ཡེལ།)',
        'hi' => 'ཧིན་དི་ཁ',
        'hi_IN' => 'ཧིན་དི་ཁ། (རྒྱ་གར།)',
        'hi_Latn' => 'ཧིན་དི་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'hi_Latn_IN' => 'ཧིན་དི་ཁ། (ལེ་ཊིན་ཡིག་གུ་, རྒྱ་གར།)',
        'hr' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ',
        'hr_BA' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ། (བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'hr_HR' => 'ཀྲོ་ཨེ་ཤི་ཡཱན་ཁ། (ཀྲོ་ཨེ་ཤ།)',
        'hu' => 'ཧཱང་གྷ་རི་ཡཱན་ཁ',
        'hu_HU' => 'ཧཱང་གྷ་རི་ཡཱན་ཁ། (ཧཱང་གྷ་རི།)',
        'hy' => 'ཨར་མི་ནི་ཡཱན་ཁ',
        'hy_AM' => 'ཨར་མི་ནི་ཡཱན་ཁ། (ཨར་མི་ནི་ཡ།)',
        'id' => 'ཨིན་ཌོ་ནེ་ཤི་ཡཱན་ཁ',
        'id_ID' => 'ཨིན་ཌོ་ནེ་ཤི་ཡཱན་ཁ། (ཨིན་ཌོ་ནེ་ཤི་ཡ།)',
        'ig' => 'ཨིག་བོ་ཁ',
        'ig_NG' => 'ཨིག་བོ་ཁ། (ནཱའི་ཇི་རི་ཡ།)',
        'is' => 'ཨ་ཡིས་ལེན་ཌིཀ་ཁ',
        'is_IS' => 'ཨ་ཡིས་ལེན་ཌིཀ་ཁ། (ཨཱའིས་ལེནཌ།)',
        'it' => 'ཨི་ཊ་ལི་ཡཱན་ཁ',
        'it_CH' => 'ཨི་ཊ་ལི་ཡཱན་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'it_IT' => 'ཨི་ཊ་ལི་ཡཱན་ཁ། (ཨི་ཊ་ལི།)',
        'it_SM' => 'ཨི་ཊ་ལི་ཡཱན་ཁ། (སཱན་མ་རི་ནོ།)',
        'it_VA' => 'ཨི་ཊ་ལི་ཡཱན་ཁ། (བ་ཊི་ཀཱན་ སི་ཊི།)',
        'ja' => 'ཇཱ་པཱ་ནིས་ཁ',
        'ja_JP' => 'ཇཱ་པཱ་ནིས་ཁ། (ཇ་པཱན།)',
        'jv' => 'ཇཱ་བ་ནིས་ཁ',
        'jv_ID' => 'ཇཱ་བ་ནིས་ཁ། (ཨིན་ཌོ་ནེ་ཤི་ཡ།)',
        'ka' => 'ཇཽ་ཇི་ཡཱན་ཁ',
        'ka_GE' => 'ཇཽ་ཇི་ཡཱན་ཁ། (ཇཽར་ཇཱ།)',
        'kk' => 'ཀ་ཛགས་ཁ',
        'kk_KZ' => 'ཀ་ཛགས་ཁ། (ཀ་ཛགས་སཏཱན།)',
        'km' => 'ཁེ་མེར་ཁ',
        'km_KH' => 'ཁེ་མེར་ཁ། (ཀམ་བྷོ་ཌི་ཡ།)',
        'kn' => 'ཀ་ན་ཌ་ཁ',
        'kn_IN' => 'ཀ་ན་ཌ་ཁ། (རྒྱ་གར།)',
        'ko' => 'ཀོ་རི་ཡཱན་ཁ',
        'ko_KP' => 'ཀོ་རི་ཡཱན་ཁ། (བྱང་ ཀོ་རི་ཡ།)',
        'ko_KR' => 'ཀོ་རི་ཡཱན་ཁ། (ལྷོ་ ཀོ་རི་ཡ།)',
        'ks' => 'ཀཱཤ་མི་རི་ཁ',
        'ks_Arab' => 'ཀཱཤ་མི་རི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ།)',
        'ks_Arab_IN' => 'ཀཱཤ་མི་རི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, རྒྱ་གར།)',
        'ks_Deva' => 'ཀཱཤ་མི་རི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ།)',
        'ks_Deva_IN' => 'ཀཱཤ་མི་རི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ་, རྒྱ་གར།)',
        'ks_IN' => 'ཀཱཤ་མི་རི་ཁ། (རྒྱ་གར།)',
        'ku' => 'ཀར་ཌིཤ་ཁ',
        'ku_TR' => 'ཀར་ཌིཤ་ཁ། (ཊཱར་ཀི།)',
        'ky' => 'ཀིར་གིས་ཁ',
        'ky_KG' => 'ཀིར་གིས་ཁ། (ཀིར་གིས་སཏཱན།)',
        'lb' => 'ལག་ཛམ་བོརྒ་ཁ',
        'lb_LU' => 'ལག་ཛམ་བོརྒ་ཁ། (ལག་ཛམ་བོརྒ།)',
        'lo' => 'ལཱ་ཝོས་ཁ',
        'lo_LA' => 'ལཱ་ཝོས་ཁ། (ལཱ་ཝོས།)',
        'lt' => 'ལི་ཐུ་ཝེ་ནི་ཡཱན་ཁ',
        'lt_LT' => 'ལི་ཐུ་ཝེ་ནི་ཡཱན་ཁ། (ལི་ཐུ་ཝེ་ནི་ཡ།)',
        'lv' => 'ལཊ་བི་ཡཱན་ཁ',
        'lv_LV' => 'ལཊ་བི་ཡཱན་ཁ། (ལཊ་བི་ཡ།)',
        'mg' => 'མ་ལ་ག་སི་ཁ',
        'mg_MG' => 'མ་ལ་ག་སི་ཁ། (མ་དཱ་གེས་ཀར།)',
        'mi' => 'མ་ཨོ་རི་ཁ',
        'mi_NZ' => 'མ་ཨོ་རི་ཁ། (ནིའུ་ཛི་ལེནཌ།)',
        'mk' => 'མ་སེ་ཌོ་ནི་ཡཱན་ཁ',
        'ml' => 'མ་ལ་ཡ་ལམ་ཁ',
        'ml_IN' => 'མ་ལ་ཡ་ལམ་ཁ། (རྒྱ་གར།)',
        'mr' => 'མ་ར་ཐི་ཁ',
        'mr_IN' => 'མ་ར་ཐི་ཁ། (རྒྱ་གར།)',
        'ms' => 'མ་ལེ་ཁ',
        'ms_BN' => 'མ་ལེ་ཁ། (བྷྲུ་ནའི།)',
        'ms_ID' => 'མ་ལེ་ཁ། (ཨིན་ཌོ་ནེ་ཤི་ཡ།)',
        'ms_MY' => 'མ་ལེ་ཁ། (མ་ལེ་ཤི་ཡ།)',
        'ms_SG' => 'མ་ལེ་ཁ། (སིང་ག་པོར།)',
        'mt' => 'མཱལ་ཊ་ཁ',
        'mt_MT' => 'མཱལ་ཊ་ཁ། (མཱལ་ཊ།)',
        'my' => 'བར་མིས་ཁ',
        'my_MM' => 'བར་མིས་ཁ། (མི་ཡཱན་མར་ [བྷར་མ]།)',
        'nb' => 'ནོར་ཝེ་ཇི་ཡཱན་བོཀ་མཱལ་ཁ',
        'nb_NO' => 'ནོར་ཝེ་ཇི་ཡཱན་བོཀ་མཱལ་ཁ། (ནོར་ཝེ།)',
        'nb_SJ' => 'ནོར་ཝེ་ཇི་ཡཱན་བོཀ་མཱལ་ཁ། (སྭཱལ་བྷརྡ་ ཨེནཌ་ ཇཱན་མ་ཡེན།)',
        'ne' => 'ནེ་པཱལི་ཁ',
        'ne_IN' => 'ནེ་པཱལི་ཁ། (རྒྱ་གར།)',
        'ne_NP' => 'ནེ་པཱལི་ཁ། (བལ་ཡུལ།)',
        'nl' => 'ཌཆ་ཁ',
        'nl_AW' => 'ཌཆ་ཁ། (ཨ་རུ་བཱ།)',
        'nl_BE' => 'ཌཆ་ཁ། (བྷེལ་ཇམ།)',
        'nl_BQ' => 'ཌཆ་ཁ། (ཀེ་རི་བི་ཡེན་ནེ་དར་ལནཌས྄།)',
        'nl_CW' => 'ཌཆ་ཁ། (ཀྱཱུར་ར་ཀོ།)',
        'nl_NL' => 'ཌཆ་ཁ། (ནེ་དར་ལནཌས྄།)',
        'nl_SR' => 'ཌཆ་ཁ། (སུ་རི་ནཱམ།)',
        'nl_SX' => 'ཌཆ་ཁ། (སིནཊ་ མཱར་ཊེན།)',
        'nn' => 'ནོར་ཝེ་ཇི་ཡཱན་ནོརསཀ་ཁ',
        'nn_NO' => 'ནོར་ཝེ་ཇི་ཡཱན་ནོརསཀ་ཁ། (ནོར་ཝེ།)',
        'no' => 'ནོར་ཝི་ཇི་ཡན་ཁ',
        'no_NO' => 'ནོར་ཝི་ཇི་ཡན་ཁ། (ནོར་ཝེ།)',
        'or' => 'ཨོ་རི་ཡ་ཁ',
        'or_IN' => 'ཨོ་རི་ཡ་ཁ། (རྒྱ་གར།)',
        'pa' => 'པཱན་ཇ་བི་ཁ',
        'pa_Arab' => 'པཱན་ཇ་བི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ།)',
        'pa_Arab_PK' => 'པཱན་ཇ་བི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, པ་ཀི་སཏཱན།)',
        'pa_Guru' => 'པཱན་ཇ་བི་ཁ། (གུ་རུ་མུ་ཁ་ཡིག་གུ།)',
        'pa_Guru_IN' => 'པཱན་ཇ་བི་ཁ། (གུ་རུ་མུ་ཁ་ཡིག་གུ་, རྒྱ་གར།)',
        'pa_IN' => 'པཱན་ཇ་བི་ཁ། (རྒྱ་གར།)',
        'pa_PK' => 'པཱན་ཇ་བི་ཁ། (པ་ཀི་སཏཱན།)',
        'pl' => 'པོ་ལིཤ་ཁ',
        'pl_PL' => 'པོ་ལིཤ་ཁ། (པོ་ལེནཌ།)',
        'ps' => 'པཱཤ་ཏོ་ཁ',
        'ps_AF' => 'པཱཤ་ཏོ་ཁ། (ཨཕ་གྷ་ནི་སཏཱན།)',
        'ps_PK' => 'པཱཤ་ཏོ་ཁ། (པ་ཀི་སཏཱན།)',
        'pt' => 'པོར་ཅུ་གིས་ཁ',
        'pt_AO' => 'པོར་ཅུ་གིས་ཁ། (ཨང་གྷོ་ལ།)',
        'pt_BR' => 'པོར་ཅུ་གིས་ཁ། (བྲ་ཛིལ།)',
        'pt_CH' => 'པོར་ཅུ་གིས་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'pt_CV' => 'པོར་ཅུ་གིས་ཁ། (ཀེཔ་བཱཌ།)',
        'pt_GQ' => 'པོར་ཅུ་གིས་ཁ། (ཨེ་ཀུ་ཊོ་རེལ་ གི་ནི།)',
        'pt_GW' => 'པོར་ཅུ་གིས་ཁ། (གྷི་ནི་ བྷི་སཱའུ།)',
        'pt_LU' => 'པོར་ཅུ་གིས་ཁ། (ལག་ཛམ་བོརྒ།)',
        'pt_MO' => 'པོར་ཅུ་གིས་ཁ། (མཀ་ཨའུ་ཅཱའི་ན།)',
        'pt_MZ' => 'པོར་ཅུ་གིས་ཁ། (མོ་ཛམ་བྷིཀ།)',
        'pt_PT' => 'པོར་ཅུ་གིས་ཁ། (པོར་ཅུ་གཱལ།)',
        'pt_ST' => 'པོར་ཅུ་གིས་ཁ། (སཝ་ ཊོ་མེ་ ཨེནཌ་ པྲྀན་སི་པེ།)',
        'pt_TL' => 'པོར་ཅུ་གིས་ཁ། (ཏི་་མོར་ལེ་ཨེསཊ།)',
        'qu' => 'ཀྭེ་ཆུ་ཨ་ཁ',
        'qu_BO' => 'ཀྭེ་ཆུ་ཨ་ཁ། (བྷེ་ལི་བི་ཡ།)',
        'qu_EC' => 'ཀྭེ་ཆུ་ཨ་ཁ། (ཨེ་ཁྭ་ཌོར།)',
        'qu_PE' => 'ཀྭེ་ཆུ་ཨ་ཁ། (པེ་རུ།)',
        'rm' => 'རོ་མེ་ནིཤ་ཁ',
        'rm_CH' => 'རོ་མེ་ནིཤ་ཁ། (སུ་ཝིཊ་ཛར་ལེནཌ།)',
        'ro' => 'རོ་མེ་ནི་ཡཱན་ཁ',
        'ro_MD' => 'རོ་མེ་ནི་ཡཱན་ཁ། (མོལ་དོ་བཱ།)',
        'ro_RO' => 'རོ་མེ་ནི་ཡཱན་ཁ། (རོ་མེ་ནི་ཡ།)',
        'ru' => 'ཨུ་རུ་སུའི་ཁ',
        'ru_BY' => 'ཨུ་རུ་སུའི་ཁ། (བེལ་ཨ་རུ་སུ།)',
        'ru_KG' => 'ཨུ་རུ་སུའི་ཁ། (ཀིར་གིས་སཏཱན།)',
        'ru_KZ' => 'ཨུ་རུ་སུའི་ཁ། (ཀ་ཛགས་སཏཱན།)',
        'ru_MD' => 'ཨུ་རུ་སུའི་ཁ། (མོལ་དོ་བཱ།)',
        'ru_RU' => 'ཨུ་རུ་སུའི་ཁ། (ཨུ་རུ་སུ།)',
        'ru_UA' => 'ཨུ་རུ་སུའི་ཁ། (ཡུ་ཀརེན།)',
        'sa' => 'སཾསྐྲྀཏ་ཁ',
        'sa_IN' => 'སཾསྐྲྀཏ་ཁ། (རྒྱ་གར།)',
        'sd' => 'སིན་དཱི་ཁ',
        'sd_Arab' => 'སིན་དཱི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ།)',
        'sd_Arab_PK' => 'སིན་དཱི་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, པ་ཀི་སཏཱན།)',
        'sd_Deva' => 'སིན་དཱི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ།)',
        'sd_Deva_IN' => 'སིན་དཱི་ཁ། (དེ་ཝ་ན་ག་རི་ཡིག་གུ་, རྒྱ་གར།)',
        'sd_IN' => 'སིན་དཱི་ཁ། (རྒྱ་གར།)',
        'sd_PK' => 'སིན་དཱི་ཁ། (པ་ཀི་སཏཱན།)',
        'si' => 'སིང་ཧ་ལ་ཁ',
        'si_LK' => 'སིང་ཧ་ལ་ཁ། (ཤྲཱི་ལང་ཀ།)',
        'sk' => 'སུ་ལོ་བཱཀ་ཁ',
        'sk_SK' => 'སུ་ལོ་བཱཀ་ཁ། (སུ་ལོ་བཱ་ཀི་ཡ།)',
        'sl' => 'སུ་ལོ་བི་ནི་ཡཱན་ཁ',
        'sl_SI' => 'སུ་ལོ་བི་ནི་ཡཱན་ཁ། (སུ་ལོ་བི་ནི་ཡ།)',
        'so' => 'སོ་མ་ལི་ཁ',
        'so_DJ' => 'སོ་མ་ལི་ཁ། (ཇི་བྷུ་ཊི།)',
        'so_ET' => 'སོ་མ་ལི་ཁ། (ཨི་ཐི་ཡོ་པི་ཡ།)',
        'so_KE' => 'སོ་མ་ལི་ཁ། (ཀེན་ཡ།)',
        'so_SO' => 'སོ་མ་ལི་ཁ། (སོ་མ་ལི་ཡ།)',
        'sq' => 'ཨཱལ་བེ་ནི་ཡཱན་ཁ',
        'sq_AL' => 'ཨཱལ་བེ་ནི་ཡཱན་ཁ། (ཨཱལ་བེ་ནི་ཡ།)',
        'sr' => 'སཱར་བྷི་ཡཱན་ཁ',
        'sr_BA' => 'སཱར་བྷི་ཡཱན་ཁ། (བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'sr_Cyrl' => 'སཱར་བྷི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ།)',
        'sr_Cyrl_BA' => 'སཱར་བྷི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'sr_Cyrl_ME' => 'སཱར་བྷི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, མོན་ཊི་ནེག་རོ།)',
        'sr_Cyrl_RS' => 'སཱར་བྷི་ཡཱན་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, སཱར་བྷི་ཡ།)',
        'sr_Latn' => 'སཱར་བྷི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'sr_Latn_BA' => 'སཱར་བྷི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ་, བྷོས་ནི་ཡ་ ཨེནཌ་ ཧར་ཛི་གྷོ་བི་ན།)',
        'sr_Latn_ME' => 'སཱར་བྷི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ་, མོན་ཊི་ནེག་རོ།)',
        'sr_Latn_RS' => 'སཱར་བྷི་ཡཱན་ཁ། (ལེ་ཊིན་ཡིག་གུ་, སཱར་བྷི་ཡ།)',
        'sr_ME' => 'སཱར་བྷི་ཡཱན་ཁ། (མོན་ཊི་ནེག་རོ།)',
        'sr_RS' => 'སཱར་བྷི་ཡཱན་ཁ། (སཱར་བྷི་ཡ།)',
        'su' => 'སཱུན་ད་ནིས་ཁ',
        'su_ID' => 'སཱུན་ད་ནིས་ཁ། (ཨིན་ཌོ་ནེ་ཤི་ཡ།)',
        'su_Latn' => 'སཱུན་ད་ནིས་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'su_Latn_ID' => 'སཱུན་ད་ནིས་ཁ། (ལེ་ཊིན་ཡིག་གུ་, ཨིན་ཌོ་ནེ་ཤི་ཡ།)',
        'sv' => 'སུའི་ཌིཤ་ཁ',
        'sv_AX' => 'སུའི་ཌིཤ་ཁ། (ཨ་ལནཌ་གླིང་ཚོམ།)',
        'sv_FI' => 'སུའི་ཌིཤ་ཁ། (ཕིན་ལེནཌ།)',
        'sv_SE' => 'སུའི་ཌིཤ་ཁ། (སུའི་ཌེན།)',
        'sw' => 'སྭཱ་ཧི་ལི་ཁ',
        'sw_CD' => 'སྭཱ་ཧི་ལི་ཁ། (ཀོང་གྷོ ཀིན་ཤ་ས།)',
        'sw_KE' => 'སྭཱ་ཧི་ལི་ཁ། (ཀེན་ཡ།)',
        'sw_TZ' => 'སྭཱ་ཧི་ལི་ཁ། (ཊཱན་ཛཱ་ནི་ཡ།)',
        'sw_UG' => 'སྭཱ་ཧི་ལི་ཁ། (ཡུ་གྷན་ཌ།)',
        'ta' => 'ཏ་མིལ་ཁ',
        'ta_IN' => 'ཏ་མིལ་ཁ། (རྒྱ་གར།)',
        'ta_LK' => 'ཏ་མིལ་ཁ། (ཤྲཱི་ལང་ཀ།)',
        'ta_MY' => 'ཏ་མིལ་ཁ། (མ་ལེ་ཤི་ཡ།)',
        'ta_SG' => 'ཏ་མིལ་ཁ། (སིང་ག་པོར།)',
        'te' => 'ཏེ་ལུ་གུ་ཁ',
        'te_IN' => 'ཏེ་ལུ་གུ་ཁ། (རྒྱ་གར།)',
        'tg' => 'ཏ་ཇིཀ་ཁ',
        'tg_TJ' => 'ཏ་ཇིཀ་ཁ། (ཏ་ཇིག་གི་སཏཱན།)',
        'th' => 'ཐཱའི་ཁ',
        'th_TH' => 'ཐཱའི་ཁ། (ཐཱའི་ལེནཌ།)',
        'ti' => 'ཏིག་རི་ཉ་ཁ',
        'ti_ER' => 'ཏིག་རི་ཉ་ཁ། (ཨེ་རི་ཊྲེ་ཡ།)',
        'ti_ET' => 'ཏིག་རི་ཉ་ཁ། (ཨི་ཐི་ཡོ་པི་ཡ།)',
        'tk' => 'ཊཱརཀ་མེན་ཁ',
        'tk_TM' => 'ཊཱརཀ་མེན་ཁ། (ཊཱརཀ་མེནའི་སཏཱན།)',
        'to' => 'ཊོང་གྷན་ཁ',
        'to_TO' => 'ཊོང་གྷན་ཁ། (ཊོང་གྷ།)',
        'tr' => 'ཊཱར་ཀིཤ་ཁ',
        'tr_CY' => 'ཊཱར་ཀིཤ་ཁ། (སཱའི་པྲས།)',
        'tr_TR' => 'ཊཱར་ཀིཤ་ཁ། (ཊཱར་ཀི།)',
        'tt' => 'ཊ་ཊར་ཁ',
        'tt_RU' => 'ཊ་ཊར་ཁ། (ཨུ་རུ་སུ།)',
        'ug' => 'ཝི་གུར་ཁ',
        'ug_CN' => 'ཝི་གུར་ཁ། (རྒྱ་ནག།)',
        'uk' => 'ཡུ་ཀེ་རེ་ནི་ཡཱན་ཁ',
        'uk_UA' => 'ཡུ་ཀེ་རེ་ནི་ཡཱན་ཁ། (ཡུ་ཀརེན།)',
        'ur' => 'ཨུར་དུ་ཁ',
        'ur_IN' => 'ཨུར་དུ་ཁ། (རྒྱ་གར།)',
        'ur_PK' => 'ཨུར་དུ་ཁ། (པ་ཀི་སཏཱན།)',
        'uz' => 'ཨུས་བེཀ་ཁ',
        'uz_AF' => 'ཨུས་བེཀ་ཁ། (ཨཕ་གྷ་ནི་སཏཱན།)',
        'uz_Arab' => 'ཨུས་བེཀ་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ།)',
        'uz_Arab_AF' => 'ཨུས་བེཀ་ཁ། (ཨེ་ར་བིཀ་ཡིག་གུ་, ཨཕ་གྷ་ནི་སཏཱན།)',
        'uz_Cyrl' => 'ཨུས་བེཀ་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ།)',
        'uz_Cyrl_UZ' => 'ཨུས་བེཀ་ཁ། (སིརིལ་ལིཀ་ཡིག་གུ་, ཨུས་བེག་གི་སཏཱན།)',
        'uz_Latn' => 'ཨུས་བེཀ་ཁ། (ལེ་ཊིན་ཡིག་གུ།)',
        'uz_Latn_UZ' => 'ཨུས་བེཀ་ཁ། (ལེ་ཊིན་ཡིག་གུ་, ཨུས་བེག་གི་སཏཱན།)',
        'uz_UZ' => 'ཨུས་བེཀ་ཁ། (ཨུས་བེག་གི་སཏཱན།)',
        'vi' => 'བེཊ་ནཱ་མིས་ཁ',
        'vi_VN' => 'བེཊ་ནཱ་མིས་ཁ། (བེཊ་ནཱམ།)',
        'wo' => 'ཝོ་ལོཕ་ཁ',
        'wo_SN' => 'ཝོ་ལོཕ་ཁ། (སེ་ནི་གྷལ།)',
        'xh' => 'ཞོ་ས་ཁ',
        'xh_ZA' => 'ཞོ་ས་ཁ། (སཱའུཐ་ ཨཕ་རི་ཀ།)',
        'yo' => 'ཡོ་རུ་བ་ཁ',
        'yo_BJ' => 'ཡོ་རུ་བ་ཁ། (བྷེ་ནིན།)',
        'yo_NG' => 'ཡོ་རུ་བ་ཁ། (ནཱའི་ཇི་རི་ཡ།)',
        'zh' => 'རྒྱ་མི་ཁ',
        'zh_CN' => 'རྒྱ་མི་ཁ། (རྒྱ་ནག།)',
        'zh_HK' => 'རྒྱ་མི་ཁ། (ཧོང་ཀོང་ཅཱའི་ན།)',
        'zh_Hans' => 'རྒྱ་མི་ཁ། (རྒྱ་ཡིག་ ལུགས་གསར་།)',
        'zh_Hans_CN' => 'རྒྱ་མི་ཁ། (རྒྱ་ཡིག་ ལུགས་གསར་་, རྒྱ་ནག།)',
        'zh_Hans_HK' => 'རྒྱ་མི་ཁ། (རྒྱ་ཡིག་ ལུགས་གསར་་, ཧོང་ཀོང་ཅཱའི་ན།)',
        'zh_Hans_MO' => 'རྒྱ་མི་ཁ། (རྒྱ་ཡིག་ ལུགས་གསར་་, མཀ་ཨའུ་ཅཱའི་ན།)',
        'zh_Hans_SG' => 'རྒྱ་མི་ཁ། (རྒྱ་ཡིག་ ལུགས་གསར་་, སིང་ག་པོར།)',
        'zh_Hant' => 'རྒྱ་མི་ཁ། (ལུགས་རྙིང་ རྒྱ་ཡིག།)',
        'zh_Hant_HK' => 'རྒྱ་མི་ཁ། (ལུགས་རྙིང་ རྒྱ་ཡིག་, ཧོང་ཀོང་ཅཱའི་ན།)',
        'zh_Hant_MO' => 'རྒྱ་མི་ཁ། (ལུགས་རྙིང་ རྒྱ་ཡིག་, མཀ་ཨའུ་ཅཱའི་ན།)',
        'zh_Hant_TW' => 'རྒྱ་མི་ཁ། (ལུགས་རྙིང་ རྒྱ་ཡིག་, ཊཱའི་ཝཱན།)',
        'zh_MO' => 'རྒྱ་མི་ཁ། (མཀ་ཨའུ་ཅཱའི་ན།)',
        'zh_SG' => 'རྒྱ་མི་ཁ། (སིང་ག་པོར།)',
        'zh_TW' => 'རྒྱ་མི་ཁ། (ཊཱའི་ཝཱན།)',
        'zu' => 'ཟུ་ལུ་ཁ',
        'zu_ZA' => 'ཟུ་ལུ་ཁ། (སཱའུཐ་ ཨཕ་རི་ཀ།)',
    ],
];
